# OPENSPACE-APP
This application is a demonstration of capabilities provided in the [openspace package](https://github.com/brandon-sexton/openspace).  Details on the backend functionality can be found on the [documentation page](https://www.openspace-docs.com).  Demonstrations are available [here](https://www.openspace-app.com/).

## Contributing
When making contributions to the openspace code repository, please follow these standards as closely as possible:
- Use [black](https://pypi.org/project/black/) to format all python code
- Use [sphinx](https://www.sphinx-doc.org/en/master/) docstrings for code documentation
- Use [PEP484](https://peps.python.org/pep-0484/) type hinting
- Open issues when making changes that are intended to be merged to the main branch
